==> ejc-ztpcdc-impl-3.0.0-20230811.071921-173-sources.jar: com/ejianc/business/dc/bean/DcDrawdistributeInfoEntity.java <==
package com.ejianc.business.dc.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;

/**
 * 图纸分发
 *
 * @author generator
 */
@TableName("dc_drawdistribute_info")
public class DcDrawdistributeInfoEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableId(value = "id")
    private Long id;
    @TableField(value = "bill_state")
    private Integer billState;
    @TableField(value = "drwgrp_id")
    private Long drwgrpId; // 卷册id
    @TableField(value = "drwgrp_code")
    private String drwgrpCode; // 卷册编号
    @TableField(value = "drwgrp_name")
    private String drwgrpName; // 卷册名称
    @TableField(value = "drwgrp_vsn")
    private String drwgrpVsn; // 卷册版本
    @TableField(value = "drwgrp_type")
    private Long drwgrpType; // 图纸类别--字典dc_drwgrp_type
    @TableField(value = "source_unitid")
    private Long sourceUnitid; // 来源单位id
    @TableField(value = "source_unitname")
    private String sourceUnitname; // 来源单位名称
    @TableField(value = "mgrp")
    private Long mgrp; // 机组--字典pub_mgrp_code
    @TableField(value = "specialty")
    private Long specialty; // 专业--字典pub_specialty_code
    @TableField(value = "sys")
    private Long sys; // 系统--字典pub_system_code
    @TableField(value = "draw_arrive_date")
    private Date drawArriveDate; // 到图日期
    @TableField(value = "issue_user_code")
    private String issueUserCode; // 签发人编号
    @TableField(value = "issue_user_name")
    private String issueUserName; // 签发人姓名
    @TableField(value = "issue_date")
    private Date issueDate; // 签发日期
    @TableField(value = "dist_code")
    private String distCode; // 分发单号
    @TableField(value = "dist_user_code")
    private String distUserCode; // 分发人编号
    @TableField(value = "dist_user_name")
    private String distUserName; // 分发人姓名
    @TableField(value = "dist_date")
    private Date distDate; // 分发日期
    @TableField(value = "create_dept_id")
    private Long createDeptId; // 创建部门id
    @TableField(value = "project_id")
    private Long projectId; // 项目ID
    @TableField(value = "project_code")
    private String projectCode; // 项目编码
    @TableField(value = "project_name")
    private String projectName; // 项目名称
    @TableField(value = "org_id")
    private Long orgId; // 所属组织id
    @TableField(value = "org_code")
    private String orgCode; // 组织编码
    @TableField(value = "org_name")
    private String orgName; // 组织名称
    @TableField(value = "parent_org_id")
    private Long parentOrgId; // 所属组织
    @TableField(value = "parent_org_code")
    private String parentOrgCode; // 所属组织编码
    @TableField(value = "parent_org_name")
    private String parentOrgName; // 所属组织名称
    @TableField(value = "surplus_num")
    private Integer surplusNum; // 库存量
    @TableField(value="drwgrp_sts")
    private String drwgrpSts; // 卷册状态(字典dc_drwgrp_sts)
    @TableField(value="flow_state")
    private String flowState; // 流程状态--字典dc_tzk
    @TableField(value="flow_state_name")
    private String flowStateName; // 流程状态名称
    @TableField(value="drwgrp_num")
    private Integer drwgrpNum; // 卷册套数

    @TableField(exist = false)
    @SubEntity(serviceName = "dcDrawdistributeDrwgrpinfoService")
    private List<DcDrawdistributeDrwgrpinfoEntity> dcDrawdistributeDrwgrpinfoEntityList = new ArrayList<>();

    @TableField(exist = false)
    @SubEntity(serviceName = "dcDrawdistributeDrawinfoService")
    private List<DcDrawdistributeDrawinfoEntity> dcDrawdistributeDrawinfoList = new ArrayList<>();

    public Long getDrwgrpId() {
        return drwgrpId;
    }

    public void setDrwgrpId(Long drwgrpId) {
        this.drwgrpId = drwgrpId;
    }

    public List<DcDrawdistributeDrwgrpinfoEntity> getDcDrawdistributeDrwgrpinfoEntityList() {
        return dcDrawdistributeDrwgrpinfoEntityList;
    }

    public void setDcDrawdistributeDrwgrpinfoEntityList(List<DcDrawdistributeDrwgrpinfoEntity> dcDrawdistributeDrwgrpinfoEntityList) {
        this.dcDrawdistributeDrwgrpinfoEntityList = dcDrawdistributeDrwgrpinfoEntityList;
    }

    public List<DcDrawdistributeDrawinfoEntity> getDcDrawdistributeDrawinfoList() {
        return dcDrawdistributeDrawinfoList;
    }

    public void setDcDrawdistributeDrawinfoList(List<DcDrawdistributeDrawinfoEntity> dcDrawdistributeDrawinfoList) {
        this.dcDrawdistributeDrawinfoList = dcDrawdistributeDrawinfoList;
    }


    @Override
    public Long getId() {
        return id;
    }

    @Override
    public void setId(Long id) {
        this.id = id;
    }

    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }

    public String getDrwgrpCode() {
        return drwgrpCode;
    }

    public void setDrwgrpCode(String drwgrpCode) {
        this.drwgrpCode = drwgrpCode;
    }

    public String getDrwgrpName() {
        return drwgrpName;
    }

    public void setDrwgrpName(String drwgrpName) {
        this.drwgrpName = drwgrpName;
    }

    public String getDrwgrpVsn() {
        return drwgrpVsn;
    }

    public void setDrwgrpVsn(String drwgrpVsn) {
        this.drwgrpVsn = drwgrpVsn;
    }

    public Long getDrwgrpType() {
        return drwgrpType;
    }

    public void setDrwgrpType(Long drwgrpType) {
        this.drwgrpType = drwgrpType;
    }

    public Long getSourceUnitid() {
        return sourceUnitid;
    }

    public void setSourceUnitid(Long sourceUnitid) {
        this.sourceUnitid = sourceUnitid;
    }

    public String getSourceUnitname() {
        return sourceUnitname;
    }

    public void setSourceUnitname(String sourceUnitname) {
        this.sourceUnitname = sourceUnitname;
    }

    public Long getMgrp() {
        return mgrp;
    }

    public void setMgrp(Long mgrp) {
        this.mgrp = mgrp;
    }

    public Long getSpecialty() {
        return specialty;
    }

    public void setSpecialty(Long specialty) {
        this.specialty = specialty;
    }

    public Long getSys() {
        return sys;
    }

    public void setSys(Long sys) {
        this.sys = sys;
    }

    public Date getDrawArriveDate() {
        return drawArriveDate;
    }

    public void setDrawArriveDate(Date drawArriveDate) {
        this.drawArriveDate = drawArriveDate;
    }

    public String getIssueUserCode() {
        return issueUserCode;
    }

    public void setIssueUserCode(String issueUserCode) {
        this.issueUserCode = issueUserCode;
    }

    public String getIssueUserName() {
        return issueUserName;
    }

    public void setIssueUserName(String issueUserName) {
        this.issueUserName = issueUserName;
    }

    public Date getIssueDate() {
        return issueDate;
    }

    public void setIssueDate(Date issueDate) {
        this.issueDate = issueDate;
    }

    public String getDistCode() {
        return distCode;
    }

    public void setDistCode(String distCode) {
        this.distCode = distCode;
    }

    public String getDistUserCode() {
        return distUserCode;
    }

    public void setDistUserCode(String distUserCode) {
        this.distUserCode = distUserCode;
    }

    public String getDistUserName() {
        return distUserName;
    }

    public void setDistUserName(String distUserName) {
        this.distUserName = distUserName;
    }

    public Date getDistDate() {
        return distDate;
    }

    public void setDistDate(Date distDate) {
        this.distDate = distDate;
    }

    public Long getCreateDeptId() {
        return createDeptId;
    }

    public void setCreateDeptId(Long createDeptId) {
        this.createDeptId = createDeptId;
    }

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }

    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }

    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }

    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public Integer getSurplusNum() {
        return surplusNum;
    }

    public void setSurplusNum(Integer surplusNum) {
        this.surplusNum = surplusNum;
    }

    public String getDrwgrpSts() {
        return drwgrpSts;
    }

    public void setDrwgrpSts(String drwgrpSts) {
        this.drwgrpSts = drwgrpSts;
    }

    public String getFlowState() {
        return flowState;
    }

    public void setFlowState(String flowState) {
        this.flowState = flowState;
    }

    public String getFlowStateName() {
        return flowStateName;
    }

    public void setFlowStateName(String flowStateName) {
        this.flowStateName = flowStateName;
    }

    public Integer getDrwgrpNum() {
        return drwgrpNum;
    }

    public void setDrwgrpNum(Integer drwgrpNum) {
        this.drwgrpNum = drwgrpNum;
    }
}

==> ejc-ztpcdc-impl-3.0.0-20231221.004858-259-sources.jar: com/ejianc/business/dc/bean/DcDrawdistributeInfoEntity.java <==
package com.ejianc.business.dc.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;

/**
 * 图纸分发
 *
 * @author generator
 */
@TableName("dc_drawdistribute_info")
public class DcDrawdistributeInfoEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableId(value = "id")
    private Long id;
    @TableField(value = "bill_state")
    private Integer billState;
    @TableField(value = "drwgrp_id")
    private Long drwgrpId; // 卷册id
    @TableField(value = "drwgrp_code")
    private String drwgrpCode; // 卷册编号
    @TableField(value = "drwgrp_name")
    private String drwgrpName; // 卷册名称
    @TableField(value = "drwgrp_vsn")
    private String drwgrpVsn; // 卷册版本
    @TableField(value = "drwgrp_type")
    private Long drwgrpType; // 图纸类别--字典dc_drwgrp_type
    @TableField(value = "source_unitid")
    private Long sourceUnitid; // 来源单位id
    @TableField(value = "source_unitname")
    private String sourceUnitname; // 来源单位名称
    @TableField(value = "mgrp")
    private Long mgrp; // 机组--字典pub_mgrp_code
    @TableField(value = "specialty")
    private Long specialty; // 专业--字典pub_specialty_code
    @TableField(value = "sys")
    private Long sys; // 系统--字典pub_system_code
    @TableField(value = "draw_arrive_date")
    private Date drawArriveDate; // 到图日期
    @TableField(value = "issue_user_code")
    private String issueUserCode; // 签发人编号
    @TableField(value = "issue_user_name")
    private String issueUserName; // 签发人姓名
    @TableField(value = "issue_date")
    private Date issueDate; // 签发日期
    @TableField(value = "dist_code")
    private String distCode; // 分发单号
    @TableField(value = "dist_user_code")
    private String distUserCode; // 分发人编号
    @TableField(value = "dist_user_name")
    private String distUserName; // 分发人姓名
    @TableField(value = "dist_date")
    private Date distDate; // 分发日期
    @TableField(value = "create_dept_id")
    private Long createDeptId; // 创建部门id
    @TableField(value = "project_id")
    private Long projectId; // 项目ID
    @TableField(value = "project_code")
    private String projectCode; // 项目编码
    @TableField(value = "project_name")
    private String projectName; // 项目名称
    @TableField(value = "org_id")
    private Long orgId; // 所属组织id
    @TableField(value = "org_code")
    private String orgCode; // 组织编码
    @TableField(value = "org_name")
    private String orgName; // 组织名称
    @TableField(value = "parent_org_id")
    private Long parentOrgId; // 所属组织
    @TableField(value = "parent_org_code")
    private String parentOrgCode; // 所属组织编码
    @TableField(value = "parent_org_name")
    private String parentOrgName; // 所属组织名称
    @TableField(value = "surplus_num")
    private Integer surplusNum; // 库存量
    @TableField(value="drwgrp_sts")
    private String drwgrpSts; // 卷册状态(字典dc_drwgrp_sts)
    @TableField(value="flow_state")
    private String flowState; // 流程状态
    @TableField(value="flow_state_name")
    private String flowStateName; // 流程状态名称
    @TableField(value="drwgrp_num")
    private Integer drwgrpNum; // 卷册套数
    @TableField(value="engineering_type_id")
    private Long engineeringTypeId; // 工程类别

    @TableField(exist = false)
    @SubEntity(serviceName = "dcDrawdistributeDrwgrpinfoService")
    private List<DcDrawdistributeDrwgrpinfoEntity> dcDrawdistributeDrwgrpinfoEntityList = new ArrayList<>();

    @TableField(exist = false)
    @SubEntity(serviceName = "dcDrawdistributeDrawinfoService")
    private List<DcDrawdistributeDrawinfoEntity> dcDrawdistributeDrawinfoList = new ArrayList<>();

    public Long getDrwgrpId() {
        return drwgrpId;
    }

    public void setDrwgrpId(Long drwgrpId) {
        this.drwgrpId = drwgrpId;
    }

    public List<DcDrawdistributeDrwgrpinfoEntity> getDcDrawdistributeDrwgrpinfoEntityList() {
        return dcDrawdistributeDrwgrpinfoEntityList;
    }

    public void setDcDrawdistributeDrwgrpinfoEntityList(List<DcDrawdistributeDrwgrpinfoEntity> dcDrawdistributeDrwgrpinfoEntityList) {
        this.dcDrawdistributeDrwgrpinfoEntityList = dcDrawdistributeDrwgrpinfoEntityList;
    }

    public List<DcDrawdistributeDrawinfoEntity> getDcDrawdistributeDrawinfoList() {
        return dcDrawdistributeDrawinfoList;
    }

    public void setDcDrawdistributeDrawinfoList(List<DcDrawdistributeDrawinfoEntity> dcDrawdistributeDrawinfoList) {
        this.dcDrawdistributeDrawinfoList = dcDrawdistributeDrawinfoList;
    }


    @Override
    public Long getId() {
        return id;
    }

    @Override
    public void setId(Long id) {
        this.id = id;
    }

    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }

    public String getDrwgrpCode() {
        return drwgrpCode;
    }

    public void setDrwgrpCode(String drwgrpCode) {
        this.drwgrpCode = drwgrpCode;
    }

    public String getDrwgrpName() {
        return drwgrpName;
    }

    public void setDrwgrpName(String drwgrpName) {
        this.drwgrpName = drwgrpName;
    }

    public String getDrwgrpVsn() {
        return drwgrpVsn;
    }

    public void setDrwgrpVsn(String drwgrpVsn) {
        this.drwgrpVsn = drwgrpVsn;
    }

    public Long getDrwgrpType() {
        return drwgrpType;
    }

    public void setDrwgrpType(Long drwgrpType) {
        this.drwgrpType = drwgrpType;
    }

    public Long getSourceUnitid() {
        return sourceUnitid;
    }

    public void setSourceUnitid(Long sourceUnitid) {
        this.sourceUnitid = sourceUnitid;
    }

    public String getSourceUnitname() {
        return sourceUnitname;
    }

    public void setSourceUnitname(String sourceUnitname) {
        this.sourceUnitname = sourceUnitname;
    }

    public Long getMgrp() {
        return mgrp;
    }

    public void setMgrp(Long mgrp) {
        this.mgrp = mgrp;
    }

    public Long getSpecialty() {
        return specialty;
    }

    public void setSpecialty(Long specialty) {
        this.specialty = specialty;
    }

    public Long getSys() {
        return sys;
    }

    public void setSys(Long sys) {
        this.sys = sys;
    }

    public Date getDrawArriveDate() {
        return drawArriveDate;
    }

    public void setDrawArriveDate(Date drawArriveDate) {
        this.drawArriveDate = drawArriveDate;
    }

    public String getIssueUserCode() {
        return issueUserCode;
    }

    public void setIssueUserCode(String issueUserCode) {
        this.issueUserCode = issueUserCode;
    }

    public String getIssueUserName() {
        return issueUserName;
    }

    public void setIssueUserName(String issueUserName) {
        this.issueUserName = issueUserName;
    }

    public Date getIssueDate() {
        return issueDate;
    }

    public void setIssueDate(Date issueDate) {
        this.issueDate = issueDate;
    }

    public String getDistCode() {
        return distCode;
    }

    public void setDistCode(String distCode) {
        this.distCode = distCode;
    }

    public String getDistUserCode() {
        return distUserCode;
    }

    public void setDistUserCode(String distUserCode) {
        this.distUserCode = distUserCode;
    }

    public String getDistUserName() {
        return distUserName;
    }

    public void setDistUserName(String distUserName) {
        this.distUserName = distUserName;
    }

    public Date getDistDate() {
        return distDate;
    }

    public void setDistDate(Date distDate) {
        this.distDate = distDate;
    }

    public Long getCreateDeptId() {
        return createDeptId;
    }

    public void setCreateDeptId(Long createDeptId) {
        this.createDeptId = createDeptId;
    }

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }

    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }

    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }

    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public Integer getSurplusNum() {
        return surplusNum;
    }

    public void setSurplusNum(Integer surplusNum) {
        this.surplusNum = surplusNum;
    }

    public String getDrwgrpSts() {
        return drwgrpSts;
    }

    public void setDrwgrpSts(String drwgrpSts) {
        this.drwgrpSts = drwgrpSts;
    }

    public String getFlowState() {
        return flowState;
    }

    public void setFlowState(String flowState) {
        this.flowState = flowState;
    }

    public String getFlowStateName() {
        return flowStateName;
    }

    public void setFlowStateName(String flowStateName) {
        this.flowStateName = flowStateName;
    }

    public Integer getDrwgrpNum() {
        return drwgrpNum;
    }

    public void setDrwgrpNum(Integer drwgrpNum) {
        this.drwgrpNum = drwgrpNum;
    }

    public Long getEngineeringTypeId() {
        return engineeringTypeId;
    }

    public void setEngineeringTypeId(Long engineeringTypeId) {
        this.engineeringTypeId = engineeringTypeId;
    }
}
